@@ -1,5 +1,7 @@
+import warnings
 import numpy as np
 from sklearn.cluster import KMeans, AgglomerativeClustering
+from sklearn.exceptions import ConvergenceWarning
 from scipy.optimize import minimize, OptimizeWarning
 
 from skgstat.util import shannon_entropy
@@ -121,7 +123,7 @@ def auto_derived_lags(distances, method_name, maxlag):
 
 
 def kmeans(distances, n, maxlag, binning_random_state=42, **kwargs):
-    """KMeans binning
+    """
     .. versionadded:: 0.3.9
 
     Clustering of pairwise separating distances between locations up to
@@ -143,14 +145,18 @@ def kmeans(distances, n, maxlag, binning_random_state=42, **kwargs):
     bin_edges : numpy.ndarray
         The **upper** bin edges of the lag classes
 
+    See Also
+    --------
+    sklearn.cluster.KMeans
+
     Note
     ----
-    The `KMeans <sklearn.cluster.KMeans>` that is used under the hood is not
+    The :class:`KMeans <sklearn.cluster.KMeans>` that is used under the hood is not
     a deterministic algorithm, as the starting cluster centroids are seeded
     randomly. This can yield slightly different results on reach run.
     Thus, for this application, the random_state on KMeans is fixed to a
     specific value. You can change the seed by passing another seed to
-    `Variogram <skgstat.Variogram>` as `binning_random_state`. 
+    :class:`Variogram <skgstat.Variogram>` as `binning_random_state`.
 
     """
     # maxlags larger than maximum separating distance will be ignored
@@ -160,8 +166,16 @@ def kmeans(distances, n, maxlag, binning_random_state=42, **kwargs):
     # filter for distances < maxlag
     d = distances[np.where(distances <= maxlag)]
 
-    # cluster the filtered distances
-    km = KMeans(n_clusters=n, random_state=binning_random_state).fit(d.reshape(-1, 1))
+    # filter the sklearn convervence warning, because working with 
+    # undefined state in binning does not make any sense
+    with warnings.catch_warnings():
+        warnings.filterwarnings('error')
+
+        # cluster the filtered distances
+        try:
+            km = KMeans(n_clusters=n, random_state=binning_random_state).fit(d.reshape(-1, 1))
+        except ConvergenceWarning:
+            raise ValueError("KMeans failed to converge. Maybe you need to use a different n_lags.")
 
     # get the centers
     _centers = np.sort(km.cluster_centers_.flatten())
@@ -174,7 +188,7 @@ def kmeans(distances, n, maxlag, binning_random_state=42, **kwargs):
 
 
 def ward(distances, n, maxlag, **kwargs):
-    """Agglomerative binning
+    """
     .. versionadded:: 0.3.9
 
     Clustering of pairwise separating distances between locations up to
@@ -199,6 +213,10 @@ def ward(distances, n, maxlag, **kwargs):
     bin_edges : numpy.ndarray
         The **upper** bin edges of the lag classes
 
+    See Also
+    --------
+    sklearn.clsuter.AgglomerativeClustering
+
     """
     # maxlags larger than maximum separating distance will be ignored
     if maxlag is None or maxlag > np.nanmax(distances):
@@ -227,7 +245,7 @@ def ward(distances, n, maxlag, **kwargs):
 
 
 def stable_entropy_lags(distances, n, maxlag, **kwargs):
-    """Stable lags
+    """
     .. versionadded: 0.4.0
 
     Optimizes the lag class edges for `n` lag classes.
