@@ -149,14 +149,29 @@ class TestVariogramInstatiation(unittest.TestCase):
         )
 
     def test_value_warning(self):
-        with self.assertRaises(Warning) as w:
-            Variogram(self.c, [42] * 30)
-        
+        with self.assertWarns(Warning) as w:
+            Variogram(self.c, [42] * 30, fit_method='lm')
+
         self.assertEqual(
             'All input values are the same.',
-            str(w.exception)
+            str(w.warning)
         )
 
+    def test_value_error_on_set_trf(self):
+        """Test the Attribute error when switching to TRF on single value input"""
+        with self.assertRaises(AttributeError) as e:
+            v = Variogram(self.c, [42] * 30, fit_method='lm')
+            v.fit_method = 'trf'
+
+        self.assertTrue("'trf' is bounded and therefore" in str(e.exception))
+    
+    def test_value_error_trf(self):
+        """Test the Attribute error on TRF instantiation on single value input"""
+        with self.assertRaises(AttributeError) as e:
+            v = Variogram(self.c, [42] * 30, fit_method='trf')
+
+        self.assertTrue("'trf' is bounded and therefore" in str(e.exception))
+
 
 class TestVariogramArguments(unittest.TestCase):
     def setUp(self):
@@ -596,6 +611,7 @@ class TestVariogramArguments(unittest.TestCase):
         V.n_lags = 5
         assert len(V.bin_count) == 5
 
+
 class TestVariogramFittingProcedure(unittest.TestCase):
     def setUp(self):
         np.random.seed(1337)
@@ -872,7 +888,18 @@ class TestVariogramFittingProcedure(unittest.TestCase):
             V.parameters,
             params,
             decimal=1
-        )      
+        )
+    
+    def test_implicit_nugget(self):
+        V = Variogram(self.c, self.v, use_nugget=False)
+
+        # no nugget used
+        self.assertTrue(V.parameters[-1] < 1e-10)
+
+        # switch to manual fitting
+        V.fit(method='manual', sill=5., nugget=2.)
+
+        self.assertTrue(abs(V.parameters[-1] - 2.) < 1e-10)
 
 
 class TestVariogramQualityMeasures(unittest.TestCase):
@@ -1096,188 +1123,6 @@ class TestVariogramMethods(unittest.TestCase):
         assert_array_almost_equal(V.parameters, param, decimal=2)
 
 
-class TestVariogramPlots(unittest.TestCase):
-    def setUp(self):
-        # set up default values, whenever c and v are not important
-        np.random.seed(42)
-        self.c = np.random.gamma(10, 4, (150, 2))
-        np.random.seed(42)
-        self.v = np.random.normal(10, 4, 150)
-
-    def test_main_plot(self):
-        V = Variogram(self.c, self.v, n_lags=5, normalize=True)
-
-        # build the figure
-        fig = V.plot(show=False)
-        ax1, ax2 = fig.axes
-
-        # test experimental
-        assert_array_almost_equal(
-            [0.71, 0.83, 1., 0.88, 0.86],
-            ax1.get_children()[1].get_data()[1],
-            decimal=2
-        )
-
-        #  test theoretical at some locations
-        assert_array_almost_equal(
-            [0.16, 0.57, 0.88, 0.89],
-            ax1.get_children()[2].get_data()[1][[4, 15, 30, 50]],
-            decimal=2
-        )
-
-    def test_main_plot_pass_axes(self):
-        V = Variogram(self.c, self.v, n_lags=5, normalize=True)
-
-        # build the figure externally
-        fig, axes = plt.subplots(1, 2)
-        fig = V.plot(axes=axes, show=False)
-        ax1, ax2 = fig.axes
-
-        # test experimental
-        assert_array_almost_equal(
-            [0.71, 0.83, 1., 0.88, 0.86],
-            ax1.get_children()[1].get_data()[1],
-            decimal=2
-        )
-
-        #  test theoretical at some locations
-        assert_array_almost_equal(
-            [0.16, 0.57, 0.88, 0.89],
-            ax1.get_children()[2].get_data()[1][[4, 15, 30, 50]],
-            decimal=2
-        )
-
-    def test_main_plot_not_normalized(self):
-        V = Variogram(self.c, self.v, n_lags=5, normalize=False)
-
-        # build the figure
-        fig = V.plot(show=False)
-        ax1, ax2 = fig.axes
-
-        # test experimental
-        assert_array_almost_equal(
-            [12.7 , 15., 17.98, 15.9, 15.39],
-            ax1.get_children()[1].get_data()[1],
-            decimal=2
-        )
-
-        #  test theoretical at some locations
-        assert_array_almost_equal(
-            [ 2.9 , 10.18, 15.86, 16.07],
-            ax1.get_children()[2].get_data()[1][[4, 15, 30, 50]],
-            decimal=2
-        )       
-
-    def test_main_plot_histogram(self):
-        V = Variogram(self.c, self.v, n_lags=5, normalize=True)
-
-        # build the figure
-        fig = V.plot(show=False)
-        childs = fig.axes[1].get_children()
-
-        # test histogram
-        for i, h in zip(range(1, 6), [5262, 4674, 1047, 142, 49]):
-            self.assertEqual(childs[i].get_height(), h)
-
-    def test_main_plot_no_histogram(self, normalize=True):
-        V = Variogram(self.c, self.v, n_lags=5)
-
-        # two axes
-        fig = V.plot(show=False)
-        self.assertEqual(len(fig.axes), 2)
-
-        fig = V.plot(hist=False, show=False)
-        self.assertEqual(len(fig.axes), 1)
-    
-    def test_location_trend(self):
-        # test that the correct amount of axes is produced
-        V = Variogram(self.c, self.v)
-
-        fig = V.location_trend(show=False)
-
-        self.assertEqual(len(fig.axes), 2)
-
-    def test_location_trend_pass_axes(self):
-        V = Variogram(self.c, self.v)
-
-        fig, axes = plt.subplots(1, 2)
-        V.location_trend(axes=axes, show=False)
-
-        # test some random y-values
-        assert_array_almost_equal(
-            [9.06, 5.95, 4.34, 10.91],
-            axes[0].get_children()[0].get_data()[1][[4, 16, 100, 140]],
-            decimal=2
-        )
-
-    def test_location_trend_raises(self):
-        V = Variogram(self.c, self.v)
-
-        with self.assertRaises(ValueError):
-            V.location_trend(axes=[0, 1, 2])
-
-    def test_distance_difference_plot(self):
-        V = Variogram(self.c, self.v, n_lags=4)
-
-        fig = V.distance_difference_plot(show=False)
-        ax = fig.axes[0]
-        
-        # test some scatter positions
-        assert_array_almost_equal(
-            [[14.77, 4.33], [30.11, 7.87], [11.32, 2.63]],
-            ax.get_children()[1].get_offsets()[[5, 112, 1337]],
-            decimal=2
-        )
-
-    def test_distance_difference_pass_ax(self):
-        V = Variogram(self.c, self.v, n_lags=4)
-
-        fig, ax = plt.subplots(1,1)
-        V.distance_difference_plot(ax=ax, show=False)
-
-        # test some scatter positions
-        assert_array_almost_equal(
-            [[14.77, 4.33], [30.11, 7.87], [11.32, 2.63]],
-            ax.get_children()[1].get_offsets()[[5, 112, 1337]],
-            decimal=2
-        )
-
-    def test_distance_difference_with_bins(self):
-        V = Variogram(self.c, self.v, n_lags=4)
-
-        fig1 = V.distance_difference_plot(show=False, plot_bins=False)
-        fig2 = V.distance_difference_plot(show=False, plot_bins=True)
-
-        # there should be one child less
-        self.assertEqual(
-            len(fig1.axes[0].get_children()),
-            len(fig2.axes[0].get_children()) - 1
-        )
-
-    def test_variogram_default_describe(self):
-        V = Variogram(self.c, self.v)
-
-        desc = V.describe()
-        self.assertTrue('params' in desc.keys())
-        self.assertTrue('kwargs' in desc.keys())
-
-    def test_variogram_describe_short(self):
-        V = Variogram(self.c, self.v)
-
-        desc = V.describe(short=True)
-        self.assertFalse('params' in desc.keys())
-        self.assertFalse('kwargs' in desc.keys())
-
-
-    def test_variogram_describe_flat(self):
-        V = Variogram(self.c, self.v)
-
-        desc = V.describe(flat=True)
-
-        # test there are no nested dicts
-        self.assertTrue(all([not isinstance(v, dict) for v in desc.values()]))
-
-
 class TestVariogramPlotlyPlots(unittest.TestCase):
     def setUp(self):
         # set up default values, whenever c and v are not important
